@@ -706,12 +706,9 @@ class Purchase(
         if Transaction().context.get('modify_header'):
             attributes.extend([
                     ('//group[@id="states"]', 'states', {'invisible': True}),
-                    ('//group[@id="amount_buttons"]',
-                        'states', {'invisible': True}),
-                    ('//page[@name="invoices"]',
-                        'states', {'invisible': True}),
-                    ('//page[@name="shipments"]',
-                        'states', {'invisible': True}),
+                    ('//group[@id="amount"]', 'states', {'invisible': True}),
+                    ('//group[@id="links"]', 'states', {'invisible': True}),
+                    ('//group[@id="buttons"]', 'states', {'invisible': True}),
                     ])
         return attributes
 
@@ -891,6 +888,17 @@ class Purchase(
                         purchase=purchase.rec_name))
         super(Purchase, cls).delete(purchases)
 
+    def on_change(self, fieldnames):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        context = Transaction().context
+        wizard_modify_header_id = ModelData.get_id(
+            'purchase', 'wizard_modify_header')
+        if (len(fieldnames) > 1
+                and context.get('action_id') == wizard_modify_header_id):
+            return []
+        return super().on_change(fieldnames)
+
     @classmethod
     @ModelView.button
     @Workflow.transition('cancelled')
